.. _matrices-docs:

========
Matrices
========

.. automodule:: diofant.matrices

.. class:: Matrix
    :module: diofant.matrices

    alias of :class:`~diofant.matrices.dense.MutableMatrix`

.. toctree::
   :caption: Contents
   :name: mattoc
   :maxdepth: 2

   matrices
   dense
   sparse
   immutablematrices
   expressions
